import { Construct } from 'constructs';
import { IModel } from './model-base';
/**
 * The model identifiers for the Bedrock base foundation models.
 *
 * @see https://docs.aws.amazon.com/bedrock/latest/userguide/model-ids-arns.html
 */
export declare class FoundationModelIdentifier {
    readonly modelId: string;
    /** Base model "ai21.j2-mid-v1". */
    static readonly AI21_LABS_JURASSIC_2_MID_V1: FoundationModelIdentifier;
    /** Base model "ai21.j2-ultra-v1". */
    static readonly AI21_LABS_JURASSIC_2_ULTRA_V1: FoundationModelIdentifier;
    /** Base model "amazon.titan-embed-text-v1". */
    static readonly AMAZON_TITAN_EMBEDDINGS_G1_TEXT_V1: FoundationModelIdentifier;
    /** Base model "amazon.titan-text-express-v1". */
    static readonly AMAZON_TITAN_TEXT_G1_EXPRESS_V1: FoundationModelIdentifier;
    /** Base model "amazon.titan-embed-image-v1". */
    static readonly AMAZON_TITAN_MULTIMODAL_EMBEDDINGS_G1_V1: FoundationModelIdentifier;
    /** Base model "amazon.titan-image-generator-v1". */
    static readonly AMAZON_TITAN_IMAGE_GENERATOR_G1_V1: FoundationModelIdentifier;
    /** Base model "anthropic.claude-v1". */
    static readonly ANTHROPIC_CLAUDE_V1: FoundationModelIdentifier;
    /** Base model "anthropic.claude-v2". */
    static readonly ANTHROPIC_CLAUDE_V2: FoundationModelIdentifier;
    /** Base model "anthropic.claude-v2:1". */
    static readonly ANTHROPIC_CLAUDE_V2_1: FoundationModelIdentifier;
    /** Base model "anthropic.claude-instant-v1". */
    static readonly ANTHROPIC_CLAUDE_INSTANT_V1: FoundationModelIdentifier;
    /** Base model "cohere.command-text-v14". */
    static readonly COHERE_COMMAND_V14: FoundationModelIdentifier;
    /** Base model "cohere.command-light-text-v14". */
    static readonly COHERE_COMMAND_LIGHT_V14: FoundationModelIdentifier;
    /** Base model "cohere.embed-english-v3". */
    static readonly COHERE_EMBED_ENGLISH_V3: FoundationModelIdentifier;
    /** Base model "cohere.embed-multilingual-v3". */
    static readonly COHERE_EMBED_MULTILINGUAL_V3: FoundationModelIdentifier;
    /** Base model "meta.llama2-13b-chat-v1". */
    static readonly META_LLAMA_2_CHAT_13B_V1: FoundationModelIdentifier;
    /** Base model "meta.llama2-70b-chat-v1". */
    static readonly META_LLAMA_2_CHAT_70B_V1: FoundationModelIdentifier;
    /**
     * Constructor for foundation model identifier
     * @param modelId the model identifier
     */
    constructor(modelId: string);
}
/**
 * A Bedrock base foundation model.
 *
 * @see https://docs.aws.amazon.com/bedrock/latest/userguide/models-supported.html
 */
export declare class FoundationModel implements IModel {
    /**
     * Construct a Bedrock base foundation model given the model identifier.
     *
     * @see https://docs.aws.amazon.com/bedrock/latest/userguide/model-ids-arns.html
     *
     * @param scope The parent construct
     * @param _id The name of the model construct
     * @param foundationModelId The model identifier such as 'amazon.titan-text-express-v1'
     * @returns A Bedrock base foundation model.
     */
    static fromFoundationModelId(scope: Construct, _id: string, foundationModelId: FoundationModelIdentifier): FoundationModel;
    /**
     * The foundation model ID.
     * @example 'amazon.titan-text-express-v1'
     */
    readonly modelId: string;
    /**
     * The foundation model ARN.
     */
    readonly modelArn: string;
    private constructor();
}
